event

package
v0.0.0-...-5f03dfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2021 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the event type in the database.
	Label = "event"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldTs holds the string denoting the ts field in the database.
	FieldTs = "ts"
	// FieldValue holds the string denoting the value field in the database.
	FieldValue = "value"
	// FieldAcked holds the string denoting the acked field in the database.
	FieldAcked = "acked"
	// FieldAckedTs holds the string denoting the ackedts field in the database.
	FieldAckedTs = "acked_ts"
	// FieldEndpointId holds the string denoting the endpointid field in the database.
	FieldEndpointId = "endpoint_id"
	// FieldTypeId holds the string denoting the typeid field in the database.
	FieldTypeId = "type_id"
	// FieldNameId holds the string denoting the nameid field in the database.
	FieldNameId = "name_id"
	// FieldLabelId holds the string denoting the labelid field in the database.
	FieldLabelId = "label_id"
	// FieldClusterId holds the string denoting the clusterid field in the database.
	FieldClusterId = "cluster_id"
	// FieldAgentId holds the string denoting the agentid field in the database.
	FieldAgentId = "agent_id"
	// FieldNodeId holds the string denoting the nodeid field in the database.
	FieldNodeId = "node_id"
	// FieldProcesId holds the string denoting the procesid field in the database.
	FieldProcesId = "proces_id"
	// FieldContainerId holds the string denoting the containerid field in the database.
	FieldContainerId = "container_id"
	// FieldPodId holds the string denoting the podid field in the database.
	FieldPodId = "pod_id"
	// EdgeMetricNameEvents holds the string denoting the metricname_events edge name in mutations.
	EdgeMetricNameEvents = "MetricName_events"
	// EdgeMetricLabelEvents holds the string denoting the metriclabel_events edge name in mutations.
	EdgeMetricLabelEvents = "MetricLabel_events"
	// EdgeMetricEndpointEvents holds the string denoting the metricendpoint_events edge name in mutations.
	EdgeMetricEndpointEvents = "MetricEndpoint_events"
	// Table holds the table name of the event in the database.
	Table = "events"
	// MetricNameEventsTable is the table that holds the MetricName_events relation/edge.
	MetricNameEventsTable = "events"
	// MetricNameEventsInverseTable is the table name for the MetricName entity.
	// It exists in this package in order to avoid circular dependency with the "metricname" package.
	MetricNameEventsInverseTable = "metricNames"
	// MetricNameEventsColumn is the table column denoting the MetricName_events relation/edge.
	MetricNameEventsColumn = "metric_name_events"
	// MetricLabelEventsTable is the table that holds the MetricLabel_events relation/edge.
	MetricLabelEventsTable = "events"
	// MetricLabelEventsInverseTable is the table name for the MetricLabel entity.
	// It exists in this package in order to avoid circular dependency with the "metriclabel" package.
	MetricLabelEventsInverseTable = "metricLabels"
	// MetricLabelEventsColumn is the table column denoting the MetricLabel_events relation/edge.
	MetricLabelEventsColumn = "metric_label_events"
	// MetricEndpointEventsTable is the table that holds the MetricEndpoint_events relation/edge.
	MetricEndpointEventsTable = "events"
	// MetricEndpointEventsInverseTable is the table name for the MetricEndpoint entity.
	// It exists in this package in order to avoid circular dependency with the "metricendpoint" package.
	MetricEndpointEventsInverseTable = "metricEndpoints"
	// MetricEndpointEventsColumn is the table column denoting the MetricEndpoint_events relation/edge.
	MetricEndpointEventsColumn = "metric_endpoint_events"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultDeletedAt holds the default value on creation for the "deleted_at" field.
	DefaultDeletedAt func() time.Time
	// UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field.
	UpdateDefaultDeletedAt func() time.Time
)

Columns holds all SQL columns for event fields.

var ForeignKeys = []string{
	"metric_endpoint_events",
	"metric_label_events",
	"metric_name_events",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "events" table and are not defined as standalone fields in the schema.

Functions

func Acked

func Acked(v bool) predicate.Event

Acked applies equality check predicate on the "acked" field. It's identical to AckedEQ.

func AckedEQ

func AckedEQ(v bool) predicate.Event

AckedEQ applies the EQ predicate on the "acked" field.

func AckedNEQ

func AckedNEQ(v bool) predicate.Event

AckedNEQ applies the NEQ predicate on the "acked" field.

func AckedTs

func AckedTs(v time.Time) predicate.Event

AckedTs applies equality check predicate on the "ackedTs" field. It's identical to AckedTsEQ.

func AckedTsEQ

func AckedTsEQ(v time.Time) predicate.Event

AckedTsEQ applies the EQ predicate on the "ackedTs" field.

func AckedTsGT

func AckedTsGT(v time.Time) predicate.Event

AckedTsGT applies the GT predicate on the "ackedTs" field.

func AckedTsGTE

func AckedTsGTE(v time.Time) predicate.Event

AckedTsGTE applies the GTE predicate on the "ackedTs" field.

func AckedTsIn

func AckedTsIn(vs ...time.Time) predicate.Event

AckedTsIn applies the In predicate on the "ackedTs" field.

func AckedTsLT

func AckedTsLT(v time.Time) predicate.Event

AckedTsLT applies the LT predicate on the "ackedTs" field.

func AckedTsLTE

func AckedTsLTE(v time.Time) predicate.Event

AckedTsLTE applies the LTE predicate on the "ackedTs" field.

func AckedTsNEQ

func AckedTsNEQ(v time.Time) predicate.Event

AckedTsNEQ applies the NEQ predicate on the "ackedTs" field.

func AckedTsNotIn

func AckedTsNotIn(vs ...time.Time) predicate.Event

AckedTsNotIn applies the NotIn predicate on the "ackedTs" field.

func AgentId

func AgentId(v uint) predicate.Event

AgentId applies equality check predicate on the "agentId" field. It's identical to AgentIdEQ.

func AgentIdEQ

func AgentIdEQ(v uint) predicate.Event

AgentIdEQ applies the EQ predicate on the "agentId" field.

func AgentIdGT

func AgentIdGT(v uint) predicate.Event

AgentIdGT applies the GT predicate on the "agentId" field.

func AgentIdGTE

func AgentIdGTE(v uint) predicate.Event

AgentIdGTE applies the GTE predicate on the "agentId" field.

func AgentIdIn

func AgentIdIn(vs ...uint) predicate.Event

AgentIdIn applies the In predicate on the "agentId" field.

func AgentIdLT

func AgentIdLT(v uint) predicate.Event

AgentIdLT applies the LT predicate on the "agentId" field.

func AgentIdLTE

func AgentIdLTE(v uint) predicate.Event

AgentIdLTE applies the LTE predicate on the "agentId" field.

func AgentIdNEQ

func AgentIdNEQ(v uint) predicate.Event

AgentIdNEQ applies the NEQ predicate on the "agentId" field.

func AgentIdNotIn

func AgentIdNotIn(vs ...uint) predicate.Event

AgentIdNotIn applies the NotIn predicate on the "agentId" field.

func And

func And(predicates ...predicate.Event) predicate.Event

And groups predicates with the AND operator between them.

func ClusterId

func ClusterId(v uint) predicate.Event

ClusterId applies equality check predicate on the "clusterId" field. It's identical to ClusterIdEQ.

func ClusterIdEQ

func ClusterIdEQ(v uint) predicate.Event

ClusterIdEQ applies the EQ predicate on the "clusterId" field.

func ClusterIdGT

func ClusterIdGT(v uint) predicate.Event

ClusterIdGT applies the GT predicate on the "clusterId" field.

func ClusterIdGTE

func ClusterIdGTE(v uint) predicate.Event

ClusterIdGTE applies the GTE predicate on the "clusterId" field.

func ClusterIdIn

func ClusterIdIn(vs ...uint) predicate.Event

ClusterIdIn applies the In predicate on the "clusterId" field.

func ClusterIdLT

func ClusterIdLT(v uint) predicate.Event

ClusterIdLT applies the LT predicate on the "clusterId" field.

func ClusterIdLTE

func ClusterIdLTE(v uint) predicate.Event

ClusterIdLTE applies the LTE predicate on the "clusterId" field.

func ClusterIdNEQ

func ClusterIdNEQ(v uint) predicate.Event

ClusterIdNEQ applies the NEQ predicate on the "clusterId" field.

func ClusterIdNotIn

func ClusterIdNotIn(vs ...uint) predicate.Event

ClusterIdNotIn applies the NotIn predicate on the "clusterId" field.

func ContainerId

func ContainerId(v uint) predicate.Event

ContainerId applies equality check predicate on the "containerId" field. It's identical to ContainerIdEQ.

func ContainerIdEQ

func ContainerIdEQ(v uint) predicate.Event

ContainerIdEQ applies the EQ predicate on the "containerId" field.

func ContainerIdGT

func ContainerIdGT(v uint) predicate.Event

ContainerIdGT applies the GT predicate on the "containerId" field.

func ContainerIdGTE

func ContainerIdGTE(v uint) predicate.Event

ContainerIdGTE applies the GTE predicate on the "containerId" field.

func ContainerIdIn

func ContainerIdIn(vs ...uint) predicate.Event

ContainerIdIn applies the In predicate on the "containerId" field.

func ContainerIdLT

func ContainerIdLT(v uint) predicate.Event

ContainerIdLT applies the LT predicate on the "containerId" field.

func ContainerIdLTE

func ContainerIdLTE(v uint) predicate.Event

ContainerIdLTE applies the LTE predicate on the "containerId" field.

func ContainerIdNEQ

func ContainerIdNEQ(v uint) predicate.Event

ContainerIdNEQ applies the NEQ predicate on the "containerId" field.

func ContainerIdNotIn

func ContainerIdNotIn(vs ...uint) predicate.Event

ContainerIdNotIn applies the NotIn predicate on the "containerId" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Event

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Event

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Event

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Event

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Event

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Event

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Event

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Event

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Event

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Event

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Event

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Event

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Event

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Event

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Event

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Event

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Event

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Event

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func EndpointId

func EndpointId(v uint) predicate.Event

EndpointId applies equality check predicate on the "endpointId" field. It's identical to EndpointIdEQ.

func EndpointIdEQ

func EndpointIdEQ(v uint) predicate.Event

EndpointIdEQ applies the EQ predicate on the "endpointId" field.

func EndpointIdGT

func EndpointIdGT(v uint) predicate.Event

EndpointIdGT applies the GT predicate on the "endpointId" field.

func EndpointIdGTE

func EndpointIdGTE(v uint) predicate.Event

EndpointIdGTE applies the GTE predicate on the "endpointId" field.

func EndpointIdIn

func EndpointIdIn(vs ...uint) predicate.Event

EndpointIdIn applies the In predicate on the "endpointId" field.

func EndpointIdLT

func EndpointIdLT(v uint) predicate.Event

EndpointIdLT applies the LT predicate on the "endpointId" field.

func EndpointIdLTE

func EndpointIdLTE(v uint) predicate.Event

EndpointIdLTE applies the LTE predicate on the "endpointId" field.

func EndpointIdNEQ

func EndpointIdNEQ(v uint) predicate.Event

EndpointIdNEQ applies the NEQ predicate on the "endpointId" field.

func EndpointIdNotIn

func EndpointIdNotIn(vs ...uint) predicate.Event

EndpointIdNotIn applies the NotIn predicate on the "endpointId" field.

func HasMetricEndpointEvents

func HasMetricEndpointEvents() predicate.Event

HasMetricEndpointEvents applies the HasEdge predicate on the "MetricEndpoint_events" edge.

func HasMetricEndpointEventsWith

func HasMetricEndpointEventsWith(preds ...predicate.MetricEndpoint) predicate.Event

HasMetricEndpointEventsWith applies the HasEdge predicate on the "MetricEndpoint_events" edge with a given conditions (other predicates).

func HasMetricLabelEvents

func HasMetricLabelEvents() predicate.Event

HasMetricLabelEvents applies the HasEdge predicate on the "MetricLabel_events" edge.

func HasMetricLabelEventsWith

func HasMetricLabelEventsWith(preds ...predicate.MetricLabel) predicate.Event

HasMetricLabelEventsWith applies the HasEdge predicate on the "MetricLabel_events" edge with a given conditions (other predicates).

func HasMetricNameEvents

func HasMetricNameEvents() predicate.Event

HasMetricNameEvents applies the HasEdge predicate on the "MetricName_events" edge.

func HasMetricNameEventsWith

func HasMetricNameEventsWith(preds ...predicate.MetricName) predicate.Event

HasMetricNameEventsWith applies the HasEdge predicate on the "MetricName_events" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Event

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Event

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Event

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Event

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Event

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Event

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Event

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Event

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Event

IDNotIn applies the NotIn predicate on the ID field.

func LabelId

func LabelId(v uint) predicate.Event

LabelId applies equality check predicate on the "labelId" field. It's identical to LabelIdEQ.

func LabelIdEQ

func LabelIdEQ(v uint) predicate.Event

LabelIdEQ applies the EQ predicate on the "labelId" field.

func LabelIdGT

func LabelIdGT(v uint) predicate.Event

LabelIdGT applies the GT predicate on the "labelId" field.

func LabelIdGTE

func LabelIdGTE(v uint) predicate.Event

LabelIdGTE applies the GTE predicate on the "labelId" field.

func LabelIdIn

func LabelIdIn(vs ...uint) predicate.Event

LabelIdIn applies the In predicate on the "labelId" field.

func LabelIdLT

func LabelIdLT(v uint) predicate.Event

LabelIdLT applies the LT predicate on the "labelId" field.

func LabelIdLTE

func LabelIdLTE(v uint) predicate.Event

LabelIdLTE applies the LTE predicate on the "labelId" field.

func LabelIdNEQ

func LabelIdNEQ(v uint) predicate.Event

LabelIdNEQ applies the NEQ predicate on the "labelId" field.

func LabelIdNotIn

func LabelIdNotIn(vs ...uint) predicate.Event

LabelIdNotIn applies the NotIn predicate on the "labelId" field.

func NameId

func NameId(v uint) predicate.Event

NameId applies equality check predicate on the "nameId" field. It's identical to NameIdEQ.

func NameIdEQ

func NameIdEQ(v uint) predicate.Event

NameIdEQ applies the EQ predicate on the "nameId" field.

func NameIdGT

func NameIdGT(v uint) predicate.Event

NameIdGT applies the GT predicate on the "nameId" field.

func NameIdGTE

func NameIdGTE(v uint) predicate.Event

NameIdGTE applies the GTE predicate on the "nameId" field.

func NameIdIn

func NameIdIn(vs ...uint) predicate.Event

NameIdIn applies the In predicate on the "nameId" field.

func NameIdLT

func NameIdLT(v uint) predicate.Event

NameIdLT applies the LT predicate on the "nameId" field.

func NameIdLTE

func NameIdLTE(v uint) predicate.Event

NameIdLTE applies the LTE predicate on the "nameId" field.

func NameIdNEQ

func NameIdNEQ(v uint) predicate.Event

NameIdNEQ applies the NEQ predicate on the "nameId" field.

func NameIdNotIn

func NameIdNotIn(vs ...uint) predicate.Event

NameIdNotIn applies the NotIn predicate on the "nameId" field.

func NodeId

func NodeId(v uint) predicate.Event

NodeId applies equality check predicate on the "nodeId" field. It's identical to NodeIdEQ.

func NodeIdEQ

func NodeIdEQ(v uint) predicate.Event

NodeIdEQ applies the EQ predicate on the "nodeId" field.

func NodeIdGT

func NodeIdGT(v uint) predicate.Event

NodeIdGT applies the GT predicate on the "nodeId" field.

func NodeIdGTE

func NodeIdGTE(v uint) predicate.Event

NodeIdGTE applies the GTE predicate on the "nodeId" field.

func NodeIdIn

func NodeIdIn(vs ...uint) predicate.Event

NodeIdIn applies the In predicate on the "nodeId" field.

func NodeIdLT

func NodeIdLT(v uint) predicate.Event

NodeIdLT applies the LT predicate on the "nodeId" field.

func NodeIdLTE

func NodeIdLTE(v uint) predicate.Event

NodeIdLTE applies the LTE predicate on the "nodeId" field.

func NodeIdNEQ

func NodeIdNEQ(v uint) predicate.Event

NodeIdNEQ applies the NEQ predicate on the "nodeId" field.

func NodeIdNotIn

func NodeIdNotIn(vs ...uint) predicate.Event

NodeIdNotIn applies the NotIn predicate on the "nodeId" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Event) predicate.Event

Or groups predicates with the OR operator between them.

func PodId

func PodId(v uint) predicate.Event

PodId applies equality check predicate on the "podId" field. It's identical to PodIdEQ.

func PodIdEQ

func PodIdEQ(v uint) predicate.Event

PodIdEQ applies the EQ predicate on the "podId" field.

func PodIdGT

func PodIdGT(v uint) predicate.Event

PodIdGT applies the GT predicate on the "podId" field.

func PodIdGTE

func PodIdGTE(v uint) predicate.Event

PodIdGTE applies the GTE predicate on the "podId" field.

func PodIdIn

func PodIdIn(vs ...uint) predicate.Event

PodIdIn applies the In predicate on the "podId" field.

func PodIdLT

func PodIdLT(v uint) predicate.Event

PodIdLT applies the LT predicate on the "podId" field.

func PodIdLTE

func PodIdLTE(v uint) predicate.Event

PodIdLTE applies the LTE predicate on the "podId" field.

func PodIdNEQ

func PodIdNEQ(v uint) predicate.Event

PodIdNEQ applies the NEQ predicate on the "podId" field.

func PodIdNotIn

func PodIdNotIn(vs ...uint) predicate.Event

PodIdNotIn applies the NotIn predicate on the "podId" field.

func ProcesId

func ProcesId(v uint) predicate.Event

ProcesId applies equality check predicate on the "procesId" field. It's identical to ProcesIdEQ.

func ProcesIdEQ

func ProcesIdEQ(v uint) predicate.Event

ProcesIdEQ applies the EQ predicate on the "procesId" field.

func ProcesIdGT

func ProcesIdGT(v uint) predicate.Event

ProcesIdGT applies the GT predicate on the "procesId" field.

func ProcesIdGTE

func ProcesIdGTE(v uint) predicate.Event

ProcesIdGTE applies the GTE predicate on the "procesId" field.

func ProcesIdIn

func ProcesIdIn(vs ...uint) predicate.Event

ProcesIdIn applies the In predicate on the "procesId" field.

func ProcesIdLT

func ProcesIdLT(v uint) predicate.Event

ProcesIdLT applies the LT predicate on the "procesId" field.

func ProcesIdLTE

func ProcesIdLTE(v uint) predicate.Event

ProcesIdLTE applies the LTE predicate on the "procesId" field.

func ProcesIdNEQ

func ProcesIdNEQ(v uint) predicate.Event

ProcesIdNEQ applies the NEQ predicate on the "procesId" field.

func ProcesIdNotIn

func ProcesIdNotIn(vs ...uint) predicate.Event

ProcesIdNotIn applies the NotIn predicate on the "procesId" field.

func Ts

func Ts(v time.Time) predicate.Event

Ts applies equality check predicate on the "ts" field. It's identical to TsEQ.

func TsEQ

func TsEQ(v time.Time) predicate.Event

TsEQ applies the EQ predicate on the "ts" field.

func TsGT

func TsGT(v time.Time) predicate.Event

TsGT applies the GT predicate on the "ts" field.

func TsGTE

func TsGTE(v time.Time) predicate.Event

TsGTE applies the GTE predicate on the "ts" field.

func TsIn

func TsIn(vs ...time.Time) predicate.Event

TsIn applies the In predicate on the "ts" field.

func TsLT

func TsLT(v time.Time) predicate.Event

TsLT applies the LT predicate on the "ts" field.

func TsLTE

func TsLTE(v time.Time) predicate.Event

TsLTE applies the LTE predicate on the "ts" field.

func TsNEQ

func TsNEQ(v time.Time) predicate.Event

TsNEQ applies the NEQ predicate on the "ts" field.

func TsNotIn

func TsNotIn(vs ...time.Time) predicate.Event

TsNotIn applies the NotIn predicate on the "ts" field.

func TypeId

func TypeId(v uint) predicate.Event

TypeId applies equality check predicate on the "typeId" field. It's identical to TypeIdEQ.

func TypeIdEQ

func TypeIdEQ(v uint) predicate.Event

TypeIdEQ applies the EQ predicate on the "typeId" field.

func TypeIdGT

func TypeIdGT(v uint) predicate.Event

TypeIdGT applies the GT predicate on the "typeId" field.

func TypeIdGTE

func TypeIdGTE(v uint) predicate.Event

TypeIdGTE applies the GTE predicate on the "typeId" field.

func TypeIdIn

func TypeIdIn(vs ...uint) predicate.Event

TypeIdIn applies the In predicate on the "typeId" field.

func TypeIdLT

func TypeIdLT(v uint) predicate.Event

TypeIdLT applies the LT predicate on the "typeId" field.

func TypeIdLTE

func TypeIdLTE(v uint) predicate.Event

TypeIdLTE applies the LTE predicate on the "typeId" field.

func TypeIdNEQ

func TypeIdNEQ(v uint) predicate.Event

TypeIdNEQ applies the NEQ predicate on the "typeId" field.

func TypeIdNotIn

func TypeIdNotIn(vs ...uint) predicate.Event

TypeIdNotIn applies the NotIn predicate on the "typeId" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Event

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Event

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Event

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Event

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Event

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Event

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Event

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Event

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Event

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Value

func Value(v float64) predicate.Event

Value applies equality check predicate on the "value" field. It's identical to ValueEQ.

func ValueEQ

func ValueEQ(v float64) predicate.Event

ValueEQ applies the EQ predicate on the "value" field.

func ValueGT

func ValueGT(v float64) predicate.Event

ValueGT applies the GT predicate on the "value" field.

func ValueGTE

func ValueGTE(v float64) predicate.Event

ValueGTE applies the GTE predicate on the "value" field.

func ValueIn

func ValueIn(vs ...float64) predicate.Event

ValueIn applies the In predicate on the "value" field.

func ValueLT

func ValueLT(v float64) predicate.Event

ValueLT applies the LT predicate on the "value" field.

func ValueLTE

func ValueLTE(v float64) predicate.Event

ValueLTE applies the LTE predicate on the "value" field.

func ValueNEQ

func ValueNEQ(v float64) predicate.Event

ValueNEQ applies the NEQ predicate on the "value" field.

func ValueNotIn

func ValueNotIn(vs ...float64) predicate.Event

ValueNotIn applies the NotIn predicate on the "value" field.

Types

This section is empty.

Jump to