k8spod

package
v0.0.0-...-5f03dfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2021 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the k8spod type in the database.
	Label = "k8s_pod"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldQos holds the string denoting the qos field in the database.
	FieldQos = "qos"
	// FieldK8sClusterId holds the string denoting the k8sclusterid field in the database.
	FieldK8sClusterId = "k8s_cluster_id"
	// FieldK8sNamespaceId holds the string denoting the k8snamespaceid field in the database.
	FieldK8sNamespaceId = "k8s_namespace_id"
	// FieldK8sObjectId holds the string denoting the k8sobjectid field in the database.
	FieldK8sObjectId = "k8s_object_id"
	// Table holds the table name of the k8spod in the database.
	Table = "k8sPods"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultDeletedAt holds the default value on creation for the "deleted_at" field.
	DefaultDeletedAt func() time.Time
	// UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field.
	UpdateDefaultDeletedAt func() time.Time
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// QosValidator is a validator for the "qos" field. It is called by the builders before save.
	QosValidator func(string) error
)

Columns holds all SQL columns for k8spod fields.

Functions

func And

func And(predicates ...predicate.K8sPod) predicate.K8sPod

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.K8sPod

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.K8sPod

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.K8sPod

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.K8sPod

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.K8sPod

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.K8sPod

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.K8sPod

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.K8sPod

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.K8sPod

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.K8sPod

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.K8sPod

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.K8sPod

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.K8sPod

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.K8sPod

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.K8sPod

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.K8sPod

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.K8sPod

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.K8sPod

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func ID

func ID(id uint) predicate.K8sPod

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uint) predicate.K8sPod

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uint) predicate.K8sPod

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uint) predicate.K8sPod

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint) predicate.K8sPod

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uint) predicate.K8sPod

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uint) predicate.K8sPod

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uint) predicate.K8sPod

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint) predicate.K8sPod

IDNotIn applies the NotIn predicate on the ID field.

func K8sClusterId

func K8sClusterId(v uint) predicate.K8sPod

K8sClusterId applies equality check predicate on the "k8sClusterId" field. It's identical to K8sClusterIdEQ.

func K8sClusterIdEQ

func K8sClusterIdEQ(v uint) predicate.K8sPod

K8sClusterIdEQ applies the EQ predicate on the "k8sClusterId" field.

func K8sClusterIdGT

func K8sClusterIdGT(v uint) predicate.K8sPod

K8sClusterIdGT applies the GT predicate on the "k8sClusterId" field.

func K8sClusterIdGTE

func K8sClusterIdGTE(v uint) predicate.K8sPod

K8sClusterIdGTE applies the GTE predicate on the "k8sClusterId" field.

func K8sClusterIdIn

func K8sClusterIdIn(vs ...uint) predicate.K8sPod

K8sClusterIdIn applies the In predicate on the "k8sClusterId" field.

func K8sClusterIdLT

func K8sClusterIdLT(v uint) predicate.K8sPod

K8sClusterIdLT applies the LT predicate on the "k8sClusterId" field.

func K8sClusterIdLTE

func K8sClusterIdLTE(v uint) predicate.K8sPod

K8sClusterIdLTE applies the LTE predicate on the "k8sClusterId" field.

func K8sClusterIdNEQ

func K8sClusterIdNEQ(v uint) predicate.K8sPod

K8sClusterIdNEQ applies the NEQ predicate on the "k8sClusterId" field.

func K8sClusterIdNotIn

func K8sClusterIdNotIn(vs ...uint) predicate.K8sPod

K8sClusterIdNotIn applies the NotIn predicate on the "k8sClusterId" field.

func K8sNamespaceId

func K8sNamespaceId(v uint) predicate.K8sPod

K8sNamespaceId applies equality check predicate on the "k8sNamespaceId" field. It's identical to K8sNamespaceIdEQ.

func K8sNamespaceIdEQ

func K8sNamespaceIdEQ(v uint) predicate.K8sPod

K8sNamespaceIdEQ applies the EQ predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdGT

func K8sNamespaceIdGT(v uint) predicate.K8sPod

K8sNamespaceIdGT applies the GT predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdGTE

func K8sNamespaceIdGTE(v uint) predicate.K8sPod

K8sNamespaceIdGTE applies the GTE predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdIn

func K8sNamespaceIdIn(vs ...uint) predicate.K8sPod

K8sNamespaceIdIn applies the In predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdLT

func K8sNamespaceIdLT(v uint) predicate.K8sPod

K8sNamespaceIdLT applies the LT predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdLTE

func K8sNamespaceIdLTE(v uint) predicate.K8sPod

K8sNamespaceIdLTE applies the LTE predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdNEQ

func K8sNamespaceIdNEQ(v uint) predicate.K8sPod

K8sNamespaceIdNEQ applies the NEQ predicate on the "k8sNamespaceId" field.

func K8sNamespaceIdNotIn

func K8sNamespaceIdNotIn(vs ...uint) predicate.K8sPod

K8sNamespaceIdNotIn applies the NotIn predicate on the "k8sNamespaceId" field.

func K8sObjectId

func K8sObjectId(v uint) predicate.K8sPod

K8sObjectId applies equality check predicate on the "k8sObjectId" field. It's identical to K8sObjectIdEQ.

func K8sObjectIdEQ

func K8sObjectIdEQ(v uint) predicate.K8sPod

K8sObjectIdEQ applies the EQ predicate on the "k8sObjectId" field.

func K8sObjectIdGT

func K8sObjectIdGT(v uint) predicate.K8sPod

K8sObjectIdGT applies the GT predicate on the "k8sObjectId" field.

func K8sObjectIdGTE

func K8sObjectIdGTE(v uint) predicate.K8sPod

K8sObjectIdGTE applies the GTE predicate on the "k8sObjectId" field.

func K8sObjectIdIn

func K8sObjectIdIn(vs ...uint) predicate.K8sPod

K8sObjectIdIn applies the In predicate on the "k8sObjectId" field.

func K8sObjectIdLT

func K8sObjectIdLT(v uint) predicate.K8sPod

K8sObjectIdLT applies the LT predicate on the "k8sObjectId" field.

func K8sObjectIdLTE

func K8sObjectIdLTE(v uint) predicate.K8sPod

K8sObjectIdLTE applies the LTE predicate on the "k8sObjectId" field.

func K8sObjectIdNEQ

func K8sObjectIdNEQ(v uint) predicate.K8sPod

K8sObjectIdNEQ applies the NEQ predicate on the "k8sObjectId" field.

func K8sObjectIdNotIn

func K8sObjectIdNotIn(vs ...uint) predicate.K8sPod

K8sObjectIdNotIn applies the NotIn predicate on the "k8sObjectId" field.

func Name

func Name(v string) predicate.K8sPod

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.K8sPod

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.K8sPod

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.K8sPod

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.K8sPod

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.K8sPod

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.K8sPod

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.K8sPod

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.K8sPod

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.K8sPod

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.K8sPod

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.K8sPod

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.K8sPod

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.K8sPod

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.K8sPod) predicate.K8sPod

Or groups predicates with the OR operator between them.

func Qos

func Qos(v string) predicate.K8sPod

Qos applies equality check predicate on the "qos" field. It's identical to QosEQ.

func QosContains

func QosContains(v string) predicate.K8sPod

QosContains applies the Contains predicate on the "qos" field.

func QosContainsFold

func QosContainsFold(v string) predicate.K8sPod

QosContainsFold applies the ContainsFold predicate on the "qos" field.

func QosEQ

func QosEQ(v string) predicate.K8sPod

QosEQ applies the EQ predicate on the "qos" field.

func QosEqualFold

func QosEqualFold(v string) predicate.K8sPod

QosEqualFold applies the EqualFold predicate on the "qos" field.

func QosGT

func QosGT(v string) predicate.K8sPod

QosGT applies the GT predicate on the "qos" field.

func QosGTE

func QosGTE(v string) predicate.K8sPod

QosGTE applies the GTE predicate on the "qos" field.

func QosHasPrefix

func QosHasPrefix(v string) predicate.K8sPod

QosHasPrefix applies the HasPrefix predicate on the "qos" field.

func QosHasSuffix

func QosHasSuffix(v string) predicate.K8sPod

QosHasSuffix applies the HasSuffix predicate on the "qos" field.

func QosIn

func QosIn(vs ...string) predicate.K8sPod

QosIn applies the In predicate on the "qos" field.

func QosLT

func QosLT(v string) predicate.K8sPod

QosLT applies the LT predicate on the "qos" field.

func QosLTE

func QosLTE(v string) predicate.K8sPod

QosLTE applies the LTE predicate on the "qos" field.

func QosNEQ

func QosNEQ(v string) predicate.K8sPod

QosNEQ applies the NEQ predicate on the "qos" field.

func QosNotIn

func QosNotIn(vs ...string) predicate.K8sPod

QosNotIn applies the NotIn predicate on the "qos" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.K8sPod

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.K8sPod

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.K8sPod

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.K8sPod

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.K8sPod

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.K8sPod

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.K8sPod

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.K8sPod

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.K8sPod

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to