process

package
v0.0.0-...-5f03dfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 11, 2021 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the process type in the database.
	Label = "process"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldPId holds the string denoting the pid field in the database.
	FieldPId = "p_id"
	// FieldCmd holds the string denoting the cmd field in the database.
	FieldCmd = "cmd"
	// FieldInfo holds the string denoting the info field in the database.
	FieldInfo = "info"
	// FieldClusterId holds the string denoting the clusterid field in the database.
	FieldClusterId = "cluster_id"
	// FieldNodeId holds the string denoting the nodeid field in the database.
	FieldNodeId = "node_id"
	// FieldContainerId holds the string denoting the containerid field in the database.
	FieldContainerId = "container_id"
	// Table holds the table name of the process in the database.
	Table = "processes"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultDeletedAt holds the default value on creation for the "deleted_at" field.
	DefaultDeletedAt func() time.Time
	// UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field.
	UpdateDefaultDeletedAt func() time.Time
)

Columns holds all SQL columns for process fields.

Functions

func And

func And(predicates ...predicate.Process) predicate.Process

And groups predicates with the AND operator between them.

func ClusterId

func ClusterId(v string) predicate.Process

ClusterId applies equality check predicate on the "clusterId" field. It's identical to ClusterIdEQ.

func ClusterIdContains

func ClusterIdContains(v string) predicate.Process

ClusterIdContains applies the Contains predicate on the "clusterId" field.

func ClusterIdContainsFold

func ClusterIdContainsFold(v string) predicate.Process

ClusterIdContainsFold applies the ContainsFold predicate on the "clusterId" field.

func ClusterIdEQ

func ClusterIdEQ(v string) predicate.Process

ClusterIdEQ applies the EQ predicate on the "clusterId" field.

func ClusterIdEqualFold

func ClusterIdEqualFold(v string) predicate.Process

ClusterIdEqualFold applies the EqualFold predicate on the "clusterId" field.

func ClusterIdGT

func ClusterIdGT(v string) predicate.Process

ClusterIdGT applies the GT predicate on the "clusterId" field.

func ClusterIdGTE

func ClusterIdGTE(v string) predicate.Process

ClusterIdGTE applies the GTE predicate on the "clusterId" field.

func ClusterIdHasPrefix

func ClusterIdHasPrefix(v string) predicate.Process

ClusterIdHasPrefix applies the HasPrefix predicate on the "clusterId" field.

func ClusterIdHasSuffix

func ClusterIdHasSuffix(v string) predicate.Process

ClusterIdHasSuffix applies the HasSuffix predicate on the "clusterId" field.

func ClusterIdIn

func ClusterIdIn(vs ...string) predicate.Process

ClusterIdIn applies the In predicate on the "clusterId" field.

func ClusterIdLT

func ClusterIdLT(v string) predicate.Process

ClusterIdLT applies the LT predicate on the "clusterId" field.

func ClusterIdLTE

func ClusterIdLTE(v string) predicate.Process

ClusterIdLTE applies the LTE predicate on the "clusterId" field.

func ClusterIdNEQ

func ClusterIdNEQ(v string) predicate.Process

ClusterIdNEQ applies the NEQ predicate on the "clusterId" field.

func ClusterIdNotIn

func ClusterIdNotIn(vs ...string) predicate.Process

ClusterIdNotIn applies the NotIn predicate on the "clusterId" field.

func Cmd

func Cmd(v string) predicate.Process

Cmd applies equality check predicate on the "cmd" field. It's identical to CmdEQ.

func CmdContains

func CmdContains(v string) predicate.Process

CmdContains applies the Contains predicate on the "cmd" field.

func CmdContainsFold

func CmdContainsFold(v string) predicate.Process

CmdContainsFold applies the ContainsFold predicate on the "cmd" field.

func CmdEQ

func CmdEQ(v string) predicate.Process

CmdEQ applies the EQ predicate on the "cmd" field.

func CmdEqualFold

func CmdEqualFold(v string) predicate.Process

CmdEqualFold applies the EqualFold predicate on the "cmd" field.

func CmdGT

func CmdGT(v string) predicate.Process

CmdGT applies the GT predicate on the "cmd" field.

func CmdGTE

func CmdGTE(v string) predicate.Process

CmdGTE applies the GTE predicate on the "cmd" field.

func CmdHasPrefix

func CmdHasPrefix(v string) predicate.Process

CmdHasPrefix applies the HasPrefix predicate on the "cmd" field.

func CmdHasSuffix

func CmdHasSuffix(v string) predicate.Process

CmdHasSuffix applies the HasSuffix predicate on the "cmd" field.

func CmdIn

func CmdIn(vs ...string) predicate.Process

CmdIn applies the In predicate on the "cmd" field.

func CmdLT

func CmdLT(v string) predicate.Process

CmdLT applies the LT predicate on the "cmd" field.

func CmdLTE

func CmdLTE(v string) predicate.Process

CmdLTE applies the LTE predicate on the "cmd" field.

func CmdNEQ

func CmdNEQ(v string) predicate.Process

CmdNEQ applies the NEQ predicate on the "cmd" field.

func CmdNotIn

func CmdNotIn(vs ...string) predicate.Process

CmdNotIn applies the NotIn predicate on the "cmd" field.

func ContainerId

func ContainerId(v string) predicate.Process

ContainerId applies equality check predicate on the "containerId" field. It's identical to ContainerIdEQ.

func ContainerIdContains

func ContainerIdContains(v string) predicate.Process

ContainerIdContains applies the Contains predicate on the "containerId" field.

func ContainerIdContainsFold

func ContainerIdContainsFold(v string) predicate.Process

ContainerIdContainsFold applies the ContainsFold predicate on the "containerId" field.

func ContainerIdEQ

func ContainerIdEQ(v string) predicate.Process

ContainerIdEQ applies the EQ predicate on the "containerId" field.

func ContainerIdEqualFold

func ContainerIdEqualFold(v string) predicate.Process

ContainerIdEqualFold applies the EqualFold predicate on the "containerId" field.

func ContainerIdGT

func ContainerIdGT(v string) predicate.Process

ContainerIdGT applies the GT predicate on the "containerId" field.

func ContainerIdGTE

func ContainerIdGTE(v string) predicate.Process

ContainerIdGTE applies the GTE predicate on the "containerId" field.

func ContainerIdHasPrefix

func ContainerIdHasPrefix(v string) predicate.Process

ContainerIdHasPrefix applies the HasPrefix predicate on the "containerId" field.

func ContainerIdHasSuffix

func ContainerIdHasSuffix(v string) predicate.Process

ContainerIdHasSuffix applies the HasSuffix predicate on the "containerId" field.

func ContainerIdIn

func ContainerIdIn(vs ...string) predicate.Process

ContainerIdIn applies the In predicate on the "containerId" field.

func ContainerIdLT

func ContainerIdLT(v string) predicate.Process

ContainerIdLT applies the LT predicate on the "containerId" field.

func ContainerIdLTE

func ContainerIdLTE(v string) predicate.Process

ContainerIdLTE applies the LTE predicate on the "containerId" field.

func ContainerIdNEQ

func ContainerIdNEQ(v string) predicate.Process

ContainerIdNEQ applies the NEQ predicate on the "containerId" field.

func ContainerIdNotIn

func ContainerIdNotIn(vs ...string) predicate.Process

ContainerIdNotIn applies the NotIn predicate on the "containerId" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Process

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Process

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Process

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Process

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Process

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Process

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Process

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Process

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Process

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Process

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Process

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Process

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Process

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Process

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Process

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Process

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Process

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Process

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func ID

func ID(id uint) predicate.Process

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uint) predicate.Process

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uint) predicate.Process

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uint) predicate.Process

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uint) predicate.Process

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uint) predicate.Process

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uint) predicate.Process

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uint) predicate.Process

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uint) predicate.Process

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Process

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Process

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Process

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Process

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Process

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Process

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Process

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Process

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Process

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Process

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Process

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Process

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Process

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Process

NameNotIn applies the NotIn predicate on the "name" field.

func NodeId

func NodeId(v string) predicate.Process

NodeId applies equality check predicate on the "nodeId" field. It's identical to NodeIdEQ.

func NodeIdContains

func NodeIdContains(v string) predicate.Process

NodeIdContains applies the Contains predicate on the "nodeId" field.

func NodeIdContainsFold

func NodeIdContainsFold(v string) predicate.Process

NodeIdContainsFold applies the ContainsFold predicate on the "nodeId" field.

func NodeIdEQ

func NodeIdEQ(v string) predicate.Process

NodeIdEQ applies the EQ predicate on the "nodeId" field.

func NodeIdEqualFold

func NodeIdEqualFold(v string) predicate.Process

NodeIdEqualFold applies the EqualFold predicate on the "nodeId" field.

func NodeIdGT

func NodeIdGT(v string) predicate.Process

NodeIdGT applies the GT predicate on the "nodeId" field.

func NodeIdGTE

func NodeIdGTE(v string) predicate.Process

NodeIdGTE applies the GTE predicate on the "nodeId" field.

func NodeIdHasPrefix

func NodeIdHasPrefix(v string) predicate.Process

NodeIdHasPrefix applies the HasPrefix predicate on the "nodeId" field.

func NodeIdHasSuffix

func NodeIdHasSuffix(v string) predicate.Process

NodeIdHasSuffix applies the HasSuffix predicate on the "nodeId" field.

func NodeIdIn

func NodeIdIn(vs ...string) predicate.Process

NodeIdIn applies the In predicate on the "nodeId" field.

func NodeIdLT

func NodeIdLT(v string) predicate.Process

NodeIdLT applies the LT predicate on the "nodeId" field.

func NodeIdLTE

func NodeIdLTE(v string) predicate.Process

NodeIdLTE applies the LTE predicate on the "nodeId" field.

func NodeIdNEQ

func NodeIdNEQ(v string) predicate.Process

NodeIdNEQ applies the NEQ predicate on the "nodeId" field.

func NodeIdNotIn

func NodeIdNotIn(vs ...string) predicate.Process

NodeIdNotIn applies the NotIn predicate on the "nodeId" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Process) predicate.Process

Or groups predicates with the OR operator between them.

func PId

func PId(v int32) predicate.Process

PId applies equality check predicate on the "pId" field. It's identical to PIdEQ.

func PIdEQ

func PIdEQ(v int32) predicate.Process

PIdEQ applies the EQ predicate on the "pId" field.

func PIdGT

func PIdGT(v int32) predicate.Process

PIdGT applies the GT predicate on the "pId" field.

func PIdGTE

func PIdGTE(v int32) predicate.Process

PIdGTE applies the GTE predicate on the "pId" field.

func PIdIn

func PIdIn(vs ...int32) predicate.Process

PIdIn applies the In predicate on the "pId" field.

func PIdLT

func PIdLT(v int32) predicate.Process

PIdLT applies the LT predicate on the "pId" field.

func PIdLTE

func PIdLTE(v int32) predicate.Process

PIdLTE applies the LTE predicate on the "pId" field.

func PIdNEQ

func PIdNEQ(v int32) predicate.Process

PIdNEQ applies the NEQ predicate on the "pId" field.

func PIdNotIn

func PIdNotIn(vs ...int32) predicate.Process

PIdNotIn applies the NotIn predicate on the "pId" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Process

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Process

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Process

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Process

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Process

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Process

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Process

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Process

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Process

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to