Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Cluster) predicate.Cluster
- func CreatedAt(v time.Time) predicate.Cluster
- func CreatedAtEQ(v time.Time) predicate.Cluster
- func CreatedAtGT(v time.Time) predicate.Cluster
- func CreatedAtGTE(v time.Time) predicate.Cluster
- func CreatedAtIn(vs ...time.Time) predicate.Cluster
- func CreatedAtLT(v time.Time) predicate.Cluster
- func CreatedAtLTE(v time.Time) predicate.Cluster
- func CreatedAtNEQ(v time.Time) predicate.Cluster
- func CreatedAtNotIn(vs ...time.Time) predicate.Cluster
- func DeletedAt(v time.Time) predicate.Cluster
- func DeletedAtEQ(v time.Time) predicate.Cluster
- func DeletedAtGT(v time.Time) predicate.Cluster
- func DeletedAtGTE(v time.Time) predicate.Cluster
- func DeletedAtIn(vs ...time.Time) predicate.Cluster
- func DeletedAtLT(v time.Time) predicate.Cluster
- func DeletedAtLTE(v time.Time) predicate.Cluster
- func DeletedAtNEQ(v time.Time) predicate.Cluster
- func DeletedAtNotIn(vs ...time.Time) predicate.Cluster
- func Description(v string) predicate.Cluster
- func DescriptionContains(v string) predicate.Cluster
- func DescriptionContainsFold(v string) predicate.Cluster
- func DescriptionEQ(v string) predicate.Cluster
- func DescriptionEqualFold(v string) predicate.Cluster
- func DescriptionGT(v string) predicate.Cluster
- func DescriptionGTE(v string) predicate.Cluster
- func DescriptionHasPrefix(v string) predicate.Cluster
- func DescriptionHasSuffix(v string) predicate.Cluster
- func DescriptionIn(vs ...string) predicate.Cluster
- func DescriptionLT(v string) predicate.Cluster
- func DescriptionLTE(v string) predicate.Cluster
- func DescriptionNEQ(v string) predicate.Cluster
- func DescriptionNotIn(vs ...string) predicate.Cluster
- func Disabled(v bool) predicate.Cluster
- func DisabledEQ(v bool) predicate.Cluster
- func DisabledNEQ(v bool) predicate.Cluster
- func HasAgents() predicate.Cluster
- func HasAgentsWith(preds ...predicate.Agent) predicate.Cluster
- func HasNodes() predicate.Cluster
- func HasNodesWith(preds ...predicate.Node) predicate.Cluster
- func ID(id uint) predicate.Cluster
- func IDEQ(id uint) predicate.Cluster
- func IDGT(id uint) predicate.Cluster
- func IDGTE(id uint) predicate.Cluster
- func IDIn(ids ...uint) predicate.Cluster
- func IDLT(id uint) predicate.Cluster
- func IDLTE(id uint) predicate.Cluster
- func IDNEQ(id uint) predicate.Cluster
- func IDNotIn(ids ...uint) predicate.Cluster
- func Name(v string) predicate.Cluster
- func NameContains(v string) predicate.Cluster
- func NameContainsFold(v string) predicate.Cluster
- func NameEQ(v string) predicate.Cluster
- func NameEqualFold(v string) predicate.Cluster
- func NameGT(v string) predicate.Cluster
- func NameGTE(v string) predicate.Cluster
- func NameHasPrefix(v string) predicate.Cluster
- func NameHasSuffix(v string) predicate.Cluster
- func NameIn(vs ...string) predicate.Cluster
- func NameLT(v string) predicate.Cluster
- func NameLTE(v string) predicate.Cluster
- func NameNEQ(v string) predicate.Cluster
- func NameNotIn(vs ...string) predicate.Cluster
- func Not(p predicate.Cluster) predicate.Cluster
- func Or(predicates ...predicate.Cluster) predicate.Cluster
- func UpdatedAt(v time.Time) predicate.Cluster
- func UpdatedAtEQ(v time.Time) predicate.Cluster
- func UpdatedAtGT(v time.Time) predicate.Cluster
- func UpdatedAtGTE(v time.Time) predicate.Cluster
- func UpdatedAtIn(vs ...time.Time) predicate.Cluster
- func UpdatedAtLT(v time.Time) predicate.Cluster
- func UpdatedAtLTE(v time.Time) predicate.Cluster
- func UpdatedAtNEQ(v time.Time) predicate.Cluster
- func UpdatedAtNotIn(vs ...time.Time) predicate.Cluster
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the cluster type in the database. Label = "cluster" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldDisabled holds the string denoting the disabled field in the database. FieldDisabled = "disabled" // EdgeAgents holds the string denoting the agents edge name in mutations. EdgeAgents = "agents" // EdgeNodes holds the string denoting the nodes edge name in mutations. EdgeNodes = "nodes" // Table holds the table name of the cluster in the database. Table = "clusters" // AgentsTable is the table that holds the agents relation/edge. AgentsTable = "agents" // AgentsInverseTable is the table name for the Agent entity. // It exists in this package in order to avoid circular dependency with the "agent" package. AgentsInverseTable = "agents" // AgentsColumn is the table column denoting the agents relation/edge. AgentsColumn = "cluster_agents" // NodesTable is the table that holds the nodes relation/edge. NodesTable = "nodes" // NodesInverseTable is the table name for the Node entity. // It exists in this package in order to avoid circular dependency with the "node" package. NodesInverseTable = "nodes" // NodesColumn is the table column denoting the nodes relation/edge. NodesColumn = "cluster_nodes" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultDeletedAt holds the default value on creation for the "deleted_at" field. DefaultDeletedAt func() time.Time // UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field. UpdateDefaultDeletedAt func() time.Time // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, FieldName, FieldDescription, FieldDisabled, }
Columns holds all SQL columns for cluster fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func Description ¶
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
DescriptionIn applies the In predicate on the "description" field.
func DescriptionLT ¶
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
DescriptionNotIn applies the NotIn predicate on the "description" field.
func Disabled ¶
Disabled applies equality check predicate on the "disabled" field. It's identical to DisabledEQ.
func DisabledEQ ¶
DisabledEQ applies the EQ predicate on the "disabled" field.
func DisabledNEQ ¶
DisabledNEQ applies the NEQ predicate on the "disabled" field.
func HasAgentsWith ¶
HasAgentsWith applies the HasEdge predicate on the "agents" edge with a given conditions (other predicates).
func HasNodesWith ¶
HasNodesWith applies the HasEdge predicate on the "nodes" edge with a given conditions (other predicates).
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.