Documentation
¶
Index ¶
- Constants
- Variables
- func Acked(v bool) predicate.Event
- func AckedEQ(v bool) predicate.Event
- func AckedNEQ(v bool) predicate.Event
- func AckedTs(v time.Time) predicate.Event
- func AckedTsEQ(v time.Time) predicate.Event
- func AckedTsGT(v time.Time) predicate.Event
- func AckedTsGTE(v time.Time) predicate.Event
- func AckedTsIn(vs ...time.Time) predicate.Event
- func AckedTsLT(v time.Time) predicate.Event
- func AckedTsLTE(v time.Time) predicate.Event
- func AckedTsNEQ(v time.Time) predicate.Event
- func AckedTsNotIn(vs ...time.Time) predicate.Event
- func AgentId(v uint) predicate.Event
- func AgentIdEQ(v uint) predicate.Event
- func AgentIdGT(v uint) predicate.Event
- func AgentIdGTE(v uint) predicate.Event
- func AgentIdIn(vs ...uint) predicate.Event
- func AgentIdLT(v uint) predicate.Event
- func AgentIdLTE(v uint) predicate.Event
- func AgentIdNEQ(v uint) predicate.Event
- func AgentIdNotIn(vs ...uint) predicate.Event
- func And(predicates ...predicate.Event) predicate.Event
- func ClusterId(v uint) predicate.Event
- func ClusterIdEQ(v uint) predicate.Event
- func ClusterIdGT(v uint) predicate.Event
- func ClusterIdGTE(v uint) predicate.Event
- func ClusterIdIn(vs ...uint) predicate.Event
- func ClusterIdLT(v uint) predicate.Event
- func ClusterIdLTE(v uint) predicate.Event
- func ClusterIdNEQ(v uint) predicate.Event
- func ClusterIdNotIn(vs ...uint) predicate.Event
- func ContainerId(v uint) predicate.Event
- func ContainerIdEQ(v uint) predicate.Event
- func ContainerIdGT(v uint) predicate.Event
- func ContainerIdGTE(v uint) predicate.Event
- func ContainerIdIn(vs ...uint) predicate.Event
- func ContainerIdLT(v uint) predicate.Event
- func ContainerIdLTE(v uint) predicate.Event
- func ContainerIdNEQ(v uint) predicate.Event
- func ContainerIdNotIn(vs ...uint) predicate.Event
- func CreatedAt(v time.Time) predicate.Event
- func CreatedAtEQ(v time.Time) predicate.Event
- func CreatedAtGT(v time.Time) predicate.Event
- func CreatedAtGTE(v time.Time) predicate.Event
- func CreatedAtIn(vs ...time.Time) predicate.Event
- func CreatedAtLT(v time.Time) predicate.Event
- func CreatedAtLTE(v time.Time) predicate.Event
- func CreatedAtNEQ(v time.Time) predicate.Event
- func CreatedAtNotIn(vs ...time.Time) predicate.Event
- func DeletedAt(v time.Time) predicate.Event
- func DeletedAtEQ(v time.Time) predicate.Event
- func DeletedAtGT(v time.Time) predicate.Event
- func DeletedAtGTE(v time.Time) predicate.Event
- func DeletedAtIn(vs ...time.Time) predicate.Event
- func DeletedAtLT(v time.Time) predicate.Event
- func DeletedAtLTE(v time.Time) predicate.Event
- func DeletedAtNEQ(v time.Time) predicate.Event
- func DeletedAtNotIn(vs ...time.Time) predicate.Event
- func EndpointId(v uint) predicate.Event
- func EndpointIdEQ(v uint) predicate.Event
- func EndpointIdGT(v uint) predicate.Event
- func EndpointIdGTE(v uint) predicate.Event
- func EndpointIdIn(vs ...uint) predicate.Event
- func EndpointIdLT(v uint) predicate.Event
- func EndpointIdLTE(v uint) predicate.Event
- func EndpointIdNEQ(v uint) predicate.Event
- func EndpointIdNotIn(vs ...uint) predicate.Event
- func HasMetricEndpointEvents() predicate.Event
- func HasMetricEndpointEventsWith(preds ...predicate.MetricEndpoint) predicate.Event
- func HasMetricLabelEvents() predicate.Event
- func HasMetricLabelEventsWith(preds ...predicate.MetricLabel) predicate.Event
- func HasMetricNameEvents() predicate.Event
- func HasMetricNameEventsWith(preds ...predicate.MetricName) predicate.Event
- func ID(id int) predicate.Event
- func IDEQ(id int) predicate.Event
- func IDGT(id int) predicate.Event
- func IDGTE(id int) predicate.Event
- func IDIn(ids ...int) predicate.Event
- func IDLT(id int) predicate.Event
- func IDLTE(id int) predicate.Event
- func IDNEQ(id int) predicate.Event
- func IDNotIn(ids ...int) predicate.Event
- func LabelId(v uint) predicate.Event
- func LabelIdEQ(v uint) predicate.Event
- func LabelIdGT(v uint) predicate.Event
- func LabelIdGTE(v uint) predicate.Event
- func LabelIdIn(vs ...uint) predicate.Event
- func LabelIdLT(v uint) predicate.Event
- func LabelIdLTE(v uint) predicate.Event
- func LabelIdNEQ(v uint) predicate.Event
- func LabelIdNotIn(vs ...uint) predicate.Event
- func NameId(v uint) predicate.Event
- func NameIdEQ(v uint) predicate.Event
- func NameIdGT(v uint) predicate.Event
- func NameIdGTE(v uint) predicate.Event
- func NameIdIn(vs ...uint) predicate.Event
- func NameIdLT(v uint) predicate.Event
- func NameIdLTE(v uint) predicate.Event
- func NameIdNEQ(v uint) predicate.Event
- func NameIdNotIn(vs ...uint) predicate.Event
- func NodeId(v uint) predicate.Event
- func NodeIdEQ(v uint) predicate.Event
- func NodeIdGT(v uint) predicate.Event
- func NodeIdGTE(v uint) predicate.Event
- func NodeIdIn(vs ...uint) predicate.Event
- func NodeIdLT(v uint) predicate.Event
- func NodeIdLTE(v uint) predicate.Event
- func NodeIdNEQ(v uint) predicate.Event
- func NodeIdNotIn(vs ...uint) predicate.Event
- func Not(p predicate.Event) predicate.Event
- func Or(predicates ...predicate.Event) predicate.Event
- func PodId(v uint) predicate.Event
- func PodIdEQ(v uint) predicate.Event
- func PodIdGT(v uint) predicate.Event
- func PodIdGTE(v uint) predicate.Event
- func PodIdIn(vs ...uint) predicate.Event
- func PodIdLT(v uint) predicate.Event
- func PodIdLTE(v uint) predicate.Event
- func PodIdNEQ(v uint) predicate.Event
- func PodIdNotIn(vs ...uint) predicate.Event
- func ProcesId(v uint) predicate.Event
- func ProcesIdEQ(v uint) predicate.Event
- func ProcesIdGT(v uint) predicate.Event
- func ProcesIdGTE(v uint) predicate.Event
- func ProcesIdIn(vs ...uint) predicate.Event
- func ProcesIdLT(v uint) predicate.Event
- func ProcesIdLTE(v uint) predicate.Event
- func ProcesIdNEQ(v uint) predicate.Event
- func ProcesIdNotIn(vs ...uint) predicate.Event
- func Ts(v time.Time) predicate.Event
- func TsEQ(v time.Time) predicate.Event
- func TsGT(v time.Time) predicate.Event
- func TsGTE(v time.Time) predicate.Event
- func TsIn(vs ...time.Time) predicate.Event
- func TsLT(v time.Time) predicate.Event
- func TsLTE(v time.Time) predicate.Event
- func TsNEQ(v time.Time) predicate.Event
- func TsNotIn(vs ...time.Time) predicate.Event
- func TypeId(v uint) predicate.Event
- func TypeIdEQ(v uint) predicate.Event
- func TypeIdGT(v uint) predicate.Event
- func TypeIdGTE(v uint) predicate.Event
- func TypeIdIn(vs ...uint) predicate.Event
- func TypeIdLT(v uint) predicate.Event
- func TypeIdLTE(v uint) predicate.Event
- func TypeIdNEQ(v uint) predicate.Event
- func TypeIdNotIn(vs ...uint) predicate.Event
- func UpdatedAt(v time.Time) predicate.Event
- func UpdatedAtEQ(v time.Time) predicate.Event
- func UpdatedAtGT(v time.Time) predicate.Event
- func UpdatedAtGTE(v time.Time) predicate.Event
- func UpdatedAtIn(vs ...time.Time) predicate.Event
- func UpdatedAtLT(v time.Time) predicate.Event
- func UpdatedAtLTE(v time.Time) predicate.Event
- func UpdatedAtNEQ(v time.Time) predicate.Event
- func UpdatedAtNotIn(vs ...time.Time) predicate.Event
- func ValidColumn(column string) bool
- func Value(v float64) predicate.Event
- func ValueEQ(v float64) predicate.Event
- func ValueGT(v float64) predicate.Event
- func ValueGTE(v float64) predicate.Event
- func ValueIn(vs ...float64) predicate.Event
- func ValueLT(v float64) predicate.Event
- func ValueLTE(v float64) predicate.Event
- func ValueNEQ(v float64) predicate.Event
- func ValueNotIn(vs ...float64) predicate.Event
Constants ¶
const ( // Label holds the string label denoting the event type in the database. Label = "event" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldTs holds the string denoting the ts field in the database. FieldTs = "ts" // FieldValue holds the string denoting the value field in the database. FieldValue = "value" // FieldAcked holds the string denoting the acked field in the database. FieldAcked = "acked" // FieldAckedTs holds the string denoting the ackedts field in the database. FieldAckedTs = "acked_ts" // FieldEndpointId holds the string denoting the endpointid field in the database. FieldEndpointId = "endpoint_id" // FieldTypeId holds the string denoting the typeid field in the database. FieldTypeId = "type_id" // FieldNameId holds the string denoting the nameid field in the database. FieldNameId = "name_id" // FieldLabelId holds the string denoting the labelid field in the database. FieldLabelId = "label_id" // FieldClusterId holds the string denoting the clusterid field in the database. FieldClusterId = "cluster_id" // FieldAgentId holds the string denoting the agentid field in the database. FieldAgentId = "agent_id" // FieldNodeId holds the string denoting the nodeid field in the database. FieldNodeId = "node_id" // FieldProcesId holds the string denoting the procesid field in the database. FieldProcesId = "proces_id" // FieldContainerId holds the string denoting the containerid field in the database. FieldContainerId = "container_id" // FieldPodId holds the string denoting the podid field in the database. FieldPodId = "pod_id" // EdgeMetricNameEvents holds the string denoting the metricname_events edge name in mutations. EdgeMetricNameEvents = "MetricName_events" // EdgeMetricLabelEvents holds the string denoting the metriclabel_events edge name in mutations. EdgeMetricLabelEvents = "MetricLabel_events" // EdgeMetricEndpointEvents holds the string denoting the metricendpoint_events edge name in mutations. EdgeMetricEndpointEvents = "MetricEndpoint_events" // Table holds the table name of the event in the database. Table = "events" // MetricNameEventsTable is the table that holds the MetricName_events relation/edge. MetricNameEventsTable = "events" // MetricNameEventsInverseTable is the table name for the MetricName entity. // It exists in this package in order to avoid circular dependency with the "metricname" package. MetricNameEventsInverseTable = "metricNames" // MetricNameEventsColumn is the table column denoting the MetricName_events relation/edge. MetricNameEventsColumn = "metric_name_events" // MetricLabelEventsTable is the table that holds the MetricLabel_events relation/edge. MetricLabelEventsTable = "events" // MetricLabelEventsInverseTable is the table name for the MetricLabel entity. // It exists in this package in order to avoid circular dependency with the "metriclabel" package. MetricLabelEventsInverseTable = "metricLabels" // MetricLabelEventsColumn is the table column denoting the MetricLabel_events relation/edge. MetricLabelEventsColumn = "metric_label_events" // MetricEndpointEventsTable is the table that holds the MetricEndpoint_events relation/edge. MetricEndpointEventsTable = "events" // MetricEndpointEventsInverseTable is the table name for the MetricEndpoint entity. // It exists in this package in order to avoid circular dependency with the "metricendpoint" package. MetricEndpointEventsInverseTable = "metricEndpoints" // MetricEndpointEventsColumn is the table column denoting the MetricEndpoint_events relation/edge. MetricEndpointEventsColumn = "metric_endpoint_events" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultDeletedAt holds the default value on creation for the "deleted_at" field. DefaultDeletedAt func() time.Time // UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field. UpdateDefaultDeletedAt func() time.Time )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, FieldTs, FieldValue, FieldAcked, FieldAckedTs, FieldEndpointId, FieldTypeId, FieldNameId, FieldLabelId, FieldClusterId, FieldAgentId, FieldNodeId, FieldProcesId, FieldContainerId, FieldPodId, }
Columns holds all SQL columns for event fields.
var ForeignKeys = []string{
"metric_endpoint_events",
"metric_label_events",
"metric_name_events",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "events" table and are not defined as standalone fields in the schema.
Functions ¶
func Acked ¶
Acked applies equality check predicate on the "acked" field. It's identical to AckedEQ.
func AckedTs ¶
AckedTs applies equality check predicate on the "ackedTs" field. It's identical to AckedTsEQ.
func AckedTsGTE ¶
AckedTsGTE applies the GTE predicate on the "ackedTs" field.
func AckedTsLTE ¶
AckedTsLTE applies the LTE predicate on the "ackedTs" field.
func AckedTsNEQ ¶
AckedTsNEQ applies the NEQ predicate on the "ackedTs" field.
func AckedTsNotIn ¶
AckedTsNotIn applies the NotIn predicate on the "ackedTs" field.
func AgentId ¶
AgentId applies equality check predicate on the "agentId" field. It's identical to AgentIdEQ.
func AgentIdGTE ¶
AgentIdGTE applies the GTE predicate on the "agentId" field.
func AgentIdLTE ¶
AgentIdLTE applies the LTE predicate on the "agentId" field.
func AgentIdNEQ ¶
AgentIdNEQ applies the NEQ predicate on the "agentId" field.
func AgentIdNotIn ¶
AgentIdNotIn applies the NotIn predicate on the "agentId" field.
func ClusterId ¶
ClusterId applies equality check predicate on the "clusterId" field. It's identical to ClusterIdEQ.
func ClusterIdEQ ¶
ClusterIdEQ applies the EQ predicate on the "clusterId" field.
func ClusterIdGT ¶
ClusterIdGT applies the GT predicate on the "clusterId" field.
func ClusterIdGTE ¶
ClusterIdGTE applies the GTE predicate on the "clusterId" field.
func ClusterIdIn ¶
ClusterIdIn applies the In predicate on the "clusterId" field.
func ClusterIdLT ¶
ClusterIdLT applies the LT predicate on the "clusterId" field.
func ClusterIdLTE ¶
ClusterIdLTE applies the LTE predicate on the "clusterId" field.
func ClusterIdNEQ ¶
ClusterIdNEQ applies the NEQ predicate on the "clusterId" field.
func ClusterIdNotIn ¶
ClusterIdNotIn applies the NotIn predicate on the "clusterId" field.
func ContainerId ¶
ContainerId applies equality check predicate on the "containerId" field. It's identical to ContainerIdEQ.
func ContainerIdEQ ¶
ContainerIdEQ applies the EQ predicate on the "containerId" field.
func ContainerIdGT ¶
ContainerIdGT applies the GT predicate on the "containerId" field.
func ContainerIdGTE ¶
ContainerIdGTE applies the GTE predicate on the "containerId" field.
func ContainerIdIn ¶
ContainerIdIn applies the In predicate on the "containerId" field.
func ContainerIdLT ¶
ContainerIdLT applies the LT predicate on the "containerId" field.
func ContainerIdLTE ¶
ContainerIdLTE applies the LTE predicate on the "containerId" field.
func ContainerIdNEQ ¶
ContainerIdNEQ applies the NEQ predicate on the "containerId" field.
func ContainerIdNotIn ¶
ContainerIdNotIn applies the NotIn predicate on the "containerId" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func EndpointId ¶
EndpointId applies equality check predicate on the "endpointId" field. It's identical to EndpointIdEQ.
func EndpointIdEQ ¶
EndpointIdEQ applies the EQ predicate on the "endpointId" field.
func EndpointIdGT ¶
EndpointIdGT applies the GT predicate on the "endpointId" field.
func EndpointIdGTE ¶
EndpointIdGTE applies the GTE predicate on the "endpointId" field.
func EndpointIdIn ¶
EndpointIdIn applies the In predicate on the "endpointId" field.
func EndpointIdLT ¶
EndpointIdLT applies the LT predicate on the "endpointId" field.
func EndpointIdLTE ¶
EndpointIdLTE applies the LTE predicate on the "endpointId" field.
func EndpointIdNEQ ¶
EndpointIdNEQ applies the NEQ predicate on the "endpointId" field.
func EndpointIdNotIn ¶
EndpointIdNotIn applies the NotIn predicate on the "endpointId" field.
func HasMetricEndpointEvents ¶
HasMetricEndpointEvents applies the HasEdge predicate on the "MetricEndpoint_events" edge.
func HasMetricEndpointEventsWith ¶
func HasMetricEndpointEventsWith(preds ...predicate.MetricEndpoint) predicate.Event
HasMetricEndpointEventsWith applies the HasEdge predicate on the "MetricEndpoint_events" edge with a given conditions (other predicates).
func HasMetricLabelEvents ¶
HasMetricLabelEvents applies the HasEdge predicate on the "MetricLabel_events" edge.
func HasMetricLabelEventsWith ¶
func HasMetricLabelEventsWith(preds ...predicate.MetricLabel) predicate.Event
HasMetricLabelEventsWith applies the HasEdge predicate on the "MetricLabel_events" edge with a given conditions (other predicates).
func HasMetricNameEvents ¶
HasMetricNameEvents applies the HasEdge predicate on the "MetricName_events" edge.
func HasMetricNameEventsWith ¶
func HasMetricNameEventsWith(preds ...predicate.MetricName) predicate.Event
HasMetricNameEventsWith applies the HasEdge predicate on the "MetricName_events" edge with a given conditions (other predicates).
func LabelId ¶
LabelId applies equality check predicate on the "labelId" field. It's identical to LabelIdEQ.
func LabelIdGTE ¶
LabelIdGTE applies the GTE predicate on the "labelId" field.
func LabelIdLTE ¶
LabelIdLTE applies the LTE predicate on the "labelId" field.
func LabelIdNEQ ¶
LabelIdNEQ applies the NEQ predicate on the "labelId" field.
func LabelIdNotIn ¶
LabelIdNotIn applies the NotIn predicate on the "labelId" field.
func NameId ¶
NameId applies equality check predicate on the "nameId" field. It's identical to NameIdEQ.
func NameIdNotIn ¶
NameIdNotIn applies the NotIn predicate on the "nameId" field.
func NodeId ¶
NodeId applies equality check predicate on the "nodeId" field. It's identical to NodeIdEQ.
func NodeIdNotIn ¶
NodeIdNotIn applies the NotIn predicate on the "nodeId" field.
func PodId ¶
PodId applies equality check predicate on the "podId" field. It's identical to PodIdEQ.
func PodIdNotIn ¶
PodIdNotIn applies the NotIn predicate on the "podId" field.
func ProcesId ¶
ProcesId applies equality check predicate on the "procesId" field. It's identical to ProcesIdEQ.
func ProcesIdEQ ¶
ProcesIdEQ applies the EQ predicate on the "procesId" field.
func ProcesIdGT ¶
ProcesIdGT applies the GT predicate on the "procesId" field.
func ProcesIdGTE ¶
ProcesIdGTE applies the GTE predicate on the "procesId" field.
func ProcesIdIn ¶
ProcesIdIn applies the In predicate on the "procesId" field.
func ProcesIdLT ¶
ProcesIdLT applies the LT predicate on the "procesId" field.
func ProcesIdLTE ¶
ProcesIdLTE applies the LTE predicate on the "procesId" field.
func ProcesIdNEQ ¶
ProcesIdNEQ applies the NEQ predicate on the "procesId" field.
func ProcesIdNotIn ¶
ProcesIdNotIn applies the NotIn predicate on the "procesId" field.
func TypeId ¶
TypeId applies equality check predicate on the "typeId" field. It's identical to TypeIdEQ.
func TypeIdNotIn ¶
TypeIdNotIn applies the NotIn predicate on the "typeId" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Value ¶
Value applies equality check predicate on the "value" field. It's identical to ValueEQ.
func ValueNotIn ¶
ValueNotIn applies the NotIn predicate on the "value" field.
Types ¶
This section is empty.