Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.K8sPod) predicate.K8sPod
- func CreatedAt(v time.Time) predicate.K8sPod
- func CreatedAtEQ(v time.Time) predicate.K8sPod
- func CreatedAtGT(v time.Time) predicate.K8sPod
- func CreatedAtGTE(v time.Time) predicate.K8sPod
- func CreatedAtIn(vs ...time.Time) predicate.K8sPod
- func CreatedAtLT(v time.Time) predicate.K8sPod
- func CreatedAtLTE(v time.Time) predicate.K8sPod
- func CreatedAtNEQ(v time.Time) predicate.K8sPod
- func CreatedAtNotIn(vs ...time.Time) predicate.K8sPod
- func DeletedAt(v time.Time) predicate.K8sPod
- func DeletedAtEQ(v time.Time) predicate.K8sPod
- func DeletedAtGT(v time.Time) predicate.K8sPod
- func DeletedAtGTE(v time.Time) predicate.K8sPod
- func DeletedAtIn(vs ...time.Time) predicate.K8sPod
- func DeletedAtLT(v time.Time) predicate.K8sPod
- func DeletedAtLTE(v time.Time) predicate.K8sPod
- func DeletedAtNEQ(v time.Time) predicate.K8sPod
- func DeletedAtNotIn(vs ...time.Time) predicate.K8sPod
- func ID(id uint) predicate.K8sPod
- func IDEQ(id uint) predicate.K8sPod
- func IDGT(id uint) predicate.K8sPod
- func IDGTE(id uint) predicate.K8sPod
- func IDIn(ids ...uint) predicate.K8sPod
- func IDLT(id uint) predicate.K8sPod
- func IDLTE(id uint) predicate.K8sPod
- func IDNEQ(id uint) predicate.K8sPod
- func IDNotIn(ids ...uint) predicate.K8sPod
- func K8sClusterId(v uint) predicate.K8sPod
- func K8sClusterIdEQ(v uint) predicate.K8sPod
- func K8sClusterIdGT(v uint) predicate.K8sPod
- func K8sClusterIdGTE(v uint) predicate.K8sPod
- func K8sClusterIdIn(vs ...uint) predicate.K8sPod
- func K8sClusterIdLT(v uint) predicate.K8sPod
- func K8sClusterIdLTE(v uint) predicate.K8sPod
- func K8sClusterIdNEQ(v uint) predicate.K8sPod
- func K8sClusterIdNotIn(vs ...uint) predicate.K8sPod
- func K8sNamespaceId(v uint) predicate.K8sPod
- func K8sNamespaceIdEQ(v uint) predicate.K8sPod
- func K8sNamespaceIdGT(v uint) predicate.K8sPod
- func K8sNamespaceIdGTE(v uint) predicate.K8sPod
- func K8sNamespaceIdIn(vs ...uint) predicate.K8sPod
- func K8sNamespaceIdLT(v uint) predicate.K8sPod
- func K8sNamespaceIdLTE(v uint) predicate.K8sPod
- func K8sNamespaceIdNEQ(v uint) predicate.K8sPod
- func K8sNamespaceIdNotIn(vs ...uint) predicate.K8sPod
- func K8sObjectId(v uint) predicate.K8sPod
- func K8sObjectIdEQ(v uint) predicate.K8sPod
- func K8sObjectIdGT(v uint) predicate.K8sPod
- func K8sObjectIdGTE(v uint) predicate.K8sPod
- func K8sObjectIdIn(vs ...uint) predicate.K8sPod
- func K8sObjectIdLT(v uint) predicate.K8sPod
- func K8sObjectIdLTE(v uint) predicate.K8sPod
- func K8sObjectIdNEQ(v uint) predicate.K8sPod
- func K8sObjectIdNotIn(vs ...uint) predicate.K8sPod
- func Name(v string) predicate.K8sPod
- func NameContains(v string) predicate.K8sPod
- func NameContainsFold(v string) predicate.K8sPod
- func NameEQ(v string) predicate.K8sPod
- func NameEqualFold(v string) predicate.K8sPod
- func NameGT(v string) predicate.K8sPod
- func NameGTE(v string) predicate.K8sPod
- func NameHasPrefix(v string) predicate.K8sPod
- func NameHasSuffix(v string) predicate.K8sPod
- func NameIn(vs ...string) predicate.K8sPod
- func NameLT(v string) predicate.K8sPod
- func NameLTE(v string) predicate.K8sPod
- func NameNEQ(v string) predicate.K8sPod
- func NameNotIn(vs ...string) predicate.K8sPod
- func Not(p predicate.K8sPod) predicate.K8sPod
- func Or(predicates ...predicate.K8sPod) predicate.K8sPod
- func Qos(v string) predicate.K8sPod
- func QosContains(v string) predicate.K8sPod
- func QosContainsFold(v string) predicate.K8sPod
- func QosEQ(v string) predicate.K8sPod
- func QosEqualFold(v string) predicate.K8sPod
- func QosGT(v string) predicate.K8sPod
- func QosGTE(v string) predicate.K8sPod
- func QosHasPrefix(v string) predicate.K8sPod
- func QosHasSuffix(v string) predicate.K8sPod
- func QosIn(vs ...string) predicate.K8sPod
- func QosLT(v string) predicate.K8sPod
- func QosLTE(v string) predicate.K8sPod
- func QosNEQ(v string) predicate.K8sPod
- func QosNotIn(vs ...string) predicate.K8sPod
- func UpdatedAt(v time.Time) predicate.K8sPod
- func UpdatedAtEQ(v time.Time) predicate.K8sPod
- func UpdatedAtGT(v time.Time) predicate.K8sPod
- func UpdatedAtGTE(v time.Time) predicate.K8sPod
- func UpdatedAtIn(vs ...time.Time) predicate.K8sPod
- func UpdatedAtLT(v time.Time) predicate.K8sPod
- func UpdatedAtLTE(v time.Time) predicate.K8sPod
- func UpdatedAtNEQ(v time.Time) predicate.K8sPod
- func UpdatedAtNotIn(vs ...time.Time) predicate.K8sPod
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the k8spod type in the database. Label = "k8s_pod" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldQos holds the string denoting the qos field in the database. FieldQos = "qos" // FieldK8sClusterId holds the string denoting the k8sclusterid field in the database. FieldK8sClusterId = "k8s_cluster_id" // FieldK8sNamespaceId holds the string denoting the k8snamespaceid field in the database. FieldK8sNamespaceId = "k8s_namespace_id" // FieldK8sObjectId holds the string denoting the k8sobjectid field in the database. FieldK8sObjectId = "k8s_object_id" // Table holds the table name of the k8spod in the database. Table = "k8sPods" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultDeletedAt holds the default value on creation for the "deleted_at" field. DefaultDeletedAt func() time.Time // UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field. UpdateDefaultDeletedAt func() time.Time // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // QosValidator is a validator for the "qos" field. It is called by the builders before save. QosValidator func(string) error )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, FieldName, FieldQos, FieldK8sClusterId, FieldK8sNamespaceId, FieldK8sObjectId, }
Columns holds all SQL columns for k8spod fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func K8sClusterId ¶
K8sClusterId applies equality check predicate on the "k8sClusterId" field. It's identical to K8sClusterIdEQ.
func K8sClusterIdEQ ¶
K8sClusterIdEQ applies the EQ predicate on the "k8sClusterId" field.
func K8sClusterIdGT ¶
K8sClusterIdGT applies the GT predicate on the "k8sClusterId" field.
func K8sClusterIdGTE ¶
K8sClusterIdGTE applies the GTE predicate on the "k8sClusterId" field.
func K8sClusterIdIn ¶
K8sClusterIdIn applies the In predicate on the "k8sClusterId" field.
func K8sClusterIdLT ¶
K8sClusterIdLT applies the LT predicate on the "k8sClusterId" field.
func K8sClusterIdLTE ¶
K8sClusterIdLTE applies the LTE predicate on the "k8sClusterId" field.
func K8sClusterIdNEQ ¶
K8sClusterIdNEQ applies the NEQ predicate on the "k8sClusterId" field.
func K8sClusterIdNotIn ¶
K8sClusterIdNotIn applies the NotIn predicate on the "k8sClusterId" field.
func K8sNamespaceId ¶
K8sNamespaceId applies equality check predicate on the "k8sNamespaceId" field. It's identical to K8sNamespaceIdEQ.
func K8sNamespaceIdEQ ¶
K8sNamespaceIdEQ applies the EQ predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdGT ¶
K8sNamespaceIdGT applies the GT predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdGTE ¶
K8sNamespaceIdGTE applies the GTE predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdIn ¶
K8sNamespaceIdIn applies the In predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdLT ¶
K8sNamespaceIdLT applies the LT predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdLTE ¶
K8sNamespaceIdLTE applies the LTE predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdNEQ ¶
K8sNamespaceIdNEQ applies the NEQ predicate on the "k8sNamespaceId" field.
func K8sNamespaceIdNotIn ¶
K8sNamespaceIdNotIn applies the NotIn predicate on the "k8sNamespaceId" field.
func K8sObjectId ¶
K8sObjectId applies equality check predicate on the "k8sObjectId" field. It's identical to K8sObjectIdEQ.
func K8sObjectIdEQ ¶
K8sObjectIdEQ applies the EQ predicate on the "k8sObjectId" field.
func K8sObjectIdGT ¶
K8sObjectIdGT applies the GT predicate on the "k8sObjectId" field.
func K8sObjectIdGTE ¶
K8sObjectIdGTE applies the GTE predicate on the "k8sObjectId" field.
func K8sObjectIdIn ¶
K8sObjectIdIn applies the In predicate on the "k8sObjectId" field.
func K8sObjectIdLT ¶
K8sObjectIdLT applies the LT predicate on the "k8sObjectId" field.
func K8sObjectIdLTE ¶
K8sObjectIdLTE applies the LTE predicate on the "k8sObjectId" field.
func K8sObjectIdNEQ ¶
K8sObjectIdNEQ applies the NEQ predicate on the "k8sObjectId" field.
func K8sObjectIdNotIn ¶
K8sObjectIdNotIn applies the NotIn predicate on the "k8sObjectId" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func QosContains ¶
QosContains applies the Contains predicate on the "qos" field.
func QosContainsFold ¶
QosContainsFold applies the ContainsFold predicate on the "qos" field.
func QosEqualFold ¶
QosEqualFold applies the EqualFold predicate on the "qos" field.
func QosHasPrefix ¶
QosHasPrefix applies the HasPrefix predicate on the "qos" field.
func QosHasSuffix ¶
QosHasSuffix applies the HasSuffix predicate on the "qos" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.