Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Process) predicate.Process
- func ClusterId(v string) predicate.Process
- func ClusterIdContains(v string) predicate.Process
- func ClusterIdContainsFold(v string) predicate.Process
- func ClusterIdEQ(v string) predicate.Process
- func ClusterIdEqualFold(v string) predicate.Process
- func ClusterIdGT(v string) predicate.Process
- func ClusterIdGTE(v string) predicate.Process
- func ClusterIdHasPrefix(v string) predicate.Process
- func ClusterIdHasSuffix(v string) predicate.Process
- func ClusterIdIn(vs ...string) predicate.Process
- func ClusterIdLT(v string) predicate.Process
- func ClusterIdLTE(v string) predicate.Process
- func ClusterIdNEQ(v string) predicate.Process
- func ClusterIdNotIn(vs ...string) predicate.Process
- func Cmd(v string) predicate.Process
- func CmdContains(v string) predicate.Process
- func CmdContainsFold(v string) predicate.Process
- func CmdEQ(v string) predicate.Process
- func CmdEqualFold(v string) predicate.Process
- func CmdGT(v string) predicate.Process
- func CmdGTE(v string) predicate.Process
- func CmdHasPrefix(v string) predicate.Process
- func CmdHasSuffix(v string) predicate.Process
- func CmdIn(vs ...string) predicate.Process
- func CmdLT(v string) predicate.Process
- func CmdLTE(v string) predicate.Process
- func CmdNEQ(v string) predicate.Process
- func CmdNotIn(vs ...string) predicate.Process
- func ContainerId(v string) predicate.Process
- func ContainerIdContains(v string) predicate.Process
- func ContainerIdContainsFold(v string) predicate.Process
- func ContainerIdEQ(v string) predicate.Process
- func ContainerIdEqualFold(v string) predicate.Process
- func ContainerIdGT(v string) predicate.Process
- func ContainerIdGTE(v string) predicate.Process
- func ContainerIdHasPrefix(v string) predicate.Process
- func ContainerIdHasSuffix(v string) predicate.Process
- func ContainerIdIn(vs ...string) predicate.Process
- func ContainerIdLT(v string) predicate.Process
- func ContainerIdLTE(v string) predicate.Process
- func ContainerIdNEQ(v string) predicate.Process
- func ContainerIdNotIn(vs ...string) predicate.Process
- func CreatedAt(v time.Time) predicate.Process
- func CreatedAtEQ(v time.Time) predicate.Process
- func CreatedAtGT(v time.Time) predicate.Process
- func CreatedAtGTE(v time.Time) predicate.Process
- func CreatedAtIn(vs ...time.Time) predicate.Process
- func CreatedAtLT(v time.Time) predicate.Process
- func CreatedAtLTE(v time.Time) predicate.Process
- func CreatedAtNEQ(v time.Time) predicate.Process
- func CreatedAtNotIn(vs ...time.Time) predicate.Process
- func DeletedAt(v time.Time) predicate.Process
- func DeletedAtEQ(v time.Time) predicate.Process
- func DeletedAtGT(v time.Time) predicate.Process
- func DeletedAtGTE(v time.Time) predicate.Process
- func DeletedAtIn(vs ...time.Time) predicate.Process
- func DeletedAtLT(v time.Time) predicate.Process
- func DeletedAtLTE(v time.Time) predicate.Process
- func DeletedAtNEQ(v time.Time) predicate.Process
- func DeletedAtNotIn(vs ...time.Time) predicate.Process
- func ID(id uint) predicate.Process
- func IDEQ(id uint) predicate.Process
- func IDGT(id uint) predicate.Process
- func IDGTE(id uint) predicate.Process
- func IDIn(ids ...uint) predicate.Process
- func IDLT(id uint) predicate.Process
- func IDLTE(id uint) predicate.Process
- func IDNEQ(id uint) predicate.Process
- func IDNotIn(ids ...uint) predicate.Process
- func Name(v string) predicate.Process
- func NameContains(v string) predicate.Process
- func NameContainsFold(v string) predicate.Process
- func NameEQ(v string) predicate.Process
- func NameEqualFold(v string) predicate.Process
- func NameGT(v string) predicate.Process
- func NameGTE(v string) predicate.Process
- func NameHasPrefix(v string) predicate.Process
- func NameHasSuffix(v string) predicate.Process
- func NameIn(vs ...string) predicate.Process
- func NameLT(v string) predicate.Process
- func NameLTE(v string) predicate.Process
- func NameNEQ(v string) predicate.Process
- func NameNotIn(vs ...string) predicate.Process
- func NodeId(v string) predicate.Process
- func NodeIdContains(v string) predicate.Process
- func NodeIdContainsFold(v string) predicate.Process
- func NodeIdEQ(v string) predicate.Process
- func NodeIdEqualFold(v string) predicate.Process
- func NodeIdGT(v string) predicate.Process
- func NodeIdGTE(v string) predicate.Process
- func NodeIdHasPrefix(v string) predicate.Process
- func NodeIdHasSuffix(v string) predicate.Process
- func NodeIdIn(vs ...string) predicate.Process
- func NodeIdLT(v string) predicate.Process
- func NodeIdLTE(v string) predicate.Process
- func NodeIdNEQ(v string) predicate.Process
- func NodeIdNotIn(vs ...string) predicate.Process
- func Not(p predicate.Process) predicate.Process
- func Or(predicates ...predicate.Process) predicate.Process
- func PId(v int32) predicate.Process
- func PIdEQ(v int32) predicate.Process
- func PIdGT(v int32) predicate.Process
- func PIdGTE(v int32) predicate.Process
- func PIdIn(vs ...int32) predicate.Process
- func PIdLT(v int32) predicate.Process
- func PIdLTE(v int32) predicate.Process
- func PIdNEQ(v int32) predicate.Process
- func PIdNotIn(vs ...int32) predicate.Process
- func UpdatedAt(v time.Time) predicate.Process
- func UpdatedAtEQ(v time.Time) predicate.Process
- func UpdatedAtGT(v time.Time) predicate.Process
- func UpdatedAtGTE(v time.Time) predicate.Process
- func UpdatedAtIn(vs ...time.Time) predicate.Process
- func UpdatedAtLT(v time.Time) predicate.Process
- func UpdatedAtLTE(v time.Time) predicate.Process
- func UpdatedAtNEQ(v time.Time) predicate.Process
- func UpdatedAtNotIn(vs ...time.Time) predicate.Process
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the process type in the database. Label = "process" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldPId holds the string denoting the pid field in the database. FieldPId = "p_id" // FieldCmd holds the string denoting the cmd field in the database. FieldCmd = "cmd" // FieldInfo holds the string denoting the info field in the database. FieldInfo = "info" // FieldClusterId holds the string denoting the clusterid field in the database. FieldClusterId = "cluster_id" // FieldNodeId holds the string denoting the nodeid field in the database. FieldNodeId = "node_id" // FieldContainerId holds the string denoting the containerid field in the database. FieldContainerId = "container_id" // Table holds the table name of the process in the database. Table = "processes" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultDeletedAt holds the default value on creation for the "deleted_at" field. DefaultDeletedAt func() time.Time // UpdateDefaultDeletedAt holds the default value on update for the "deleted_at" field. UpdateDefaultDeletedAt func() time.Time )
var Columns = []string{ FieldID, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, FieldName, FieldPId, FieldCmd, FieldInfo, FieldClusterId, FieldNodeId, FieldContainerId, }
Columns holds all SQL columns for process fields.
Functions ¶
func ClusterId ¶
ClusterId applies equality check predicate on the "clusterId" field. It's identical to ClusterIdEQ.
func ClusterIdContains ¶
ClusterIdContains applies the Contains predicate on the "clusterId" field.
func ClusterIdContainsFold ¶
ClusterIdContainsFold applies the ContainsFold predicate on the "clusterId" field.
func ClusterIdEQ ¶
ClusterIdEQ applies the EQ predicate on the "clusterId" field.
func ClusterIdEqualFold ¶
ClusterIdEqualFold applies the EqualFold predicate on the "clusterId" field.
func ClusterIdGT ¶
ClusterIdGT applies the GT predicate on the "clusterId" field.
func ClusterIdGTE ¶
ClusterIdGTE applies the GTE predicate on the "clusterId" field.
func ClusterIdHasPrefix ¶
ClusterIdHasPrefix applies the HasPrefix predicate on the "clusterId" field.
func ClusterIdHasSuffix ¶
ClusterIdHasSuffix applies the HasSuffix predicate on the "clusterId" field.
func ClusterIdIn ¶
ClusterIdIn applies the In predicate on the "clusterId" field.
func ClusterIdLT ¶
ClusterIdLT applies the LT predicate on the "clusterId" field.
func ClusterIdLTE ¶
ClusterIdLTE applies the LTE predicate on the "clusterId" field.
func ClusterIdNEQ ¶
ClusterIdNEQ applies the NEQ predicate on the "clusterId" field.
func ClusterIdNotIn ¶
ClusterIdNotIn applies the NotIn predicate on the "clusterId" field.
func CmdContains ¶
CmdContains applies the Contains predicate on the "cmd" field.
func CmdContainsFold ¶
CmdContainsFold applies the ContainsFold predicate on the "cmd" field.
func CmdEqualFold ¶
CmdEqualFold applies the EqualFold predicate on the "cmd" field.
func CmdHasPrefix ¶
CmdHasPrefix applies the HasPrefix predicate on the "cmd" field.
func CmdHasSuffix ¶
CmdHasSuffix applies the HasSuffix predicate on the "cmd" field.
func ContainerId ¶
ContainerId applies equality check predicate on the "containerId" field. It's identical to ContainerIdEQ.
func ContainerIdContains ¶
ContainerIdContains applies the Contains predicate on the "containerId" field.
func ContainerIdContainsFold ¶
ContainerIdContainsFold applies the ContainsFold predicate on the "containerId" field.
func ContainerIdEQ ¶
ContainerIdEQ applies the EQ predicate on the "containerId" field.
func ContainerIdEqualFold ¶
ContainerIdEqualFold applies the EqualFold predicate on the "containerId" field.
func ContainerIdGT ¶
ContainerIdGT applies the GT predicate on the "containerId" field.
func ContainerIdGTE ¶
ContainerIdGTE applies the GTE predicate on the "containerId" field.
func ContainerIdHasPrefix ¶
ContainerIdHasPrefix applies the HasPrefix predicate on the "containerId" field.
func ContainerIdHasSuffix ¶
ContainerIdHasSuffix applies the HasSuffix predicate on the "containerId" field.
func ContainerIdIn ¶
ContainerIdIn applies the In predicate on the "containerId" field.
func ContainerIdLT ¶
ContainerIdLT applies the LT predicate on the "containerId" field.
func ContainerIdLTE ¶
ContainerIdLTE applies the LTE predicate on the "containerId" field.
func ContainerIdNEQ ¶
ContainerIdNEQ applies the NEQ predicate on the "containerId" field.
func ContainerIdNotIn ¶
ContainerIdNotIn applies the NotIn predicate on the "containerId" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NodeId ¶
NodeId applies equality check predicate on the "nodeId" field. It's identical to NodeIdEQ.
func NodeIdContains ¶
NodeIdContains applies the Contains predicate on the "nodeId" field.
func NodeIdContainsFold ¶
NodeIdContainsFold applies the ContainsFold predicate on the "nodeId" field.
func NodeIdEqualFold ¶
NodeIdEqualFold applies the EqualFold predicate on the "nodeId" field.
func NodeIdHasPrefix ¶
NodeIdHasPrefix applies the HasPrefix predicate on the "nodeId" field.
func NodeIdHasSuffix ¶
NodeIdHasSuffix applies the HasSuffix predicate on the "nodeId" field.
func NodeIdNotIn ¶
NodeIdNotIn applies the NotIn predicate on the "nodeId" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.